@@ -114,7 +114,6 @@ Where each Group Record has the following internal format::
    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 """
 
-import six
 import struct
 from math import trunc
 
@@ -308,7 +307,7 @@ class igmpv3_query(igmp):
         if 0 == self.csum:
             self.csum = packet_utils.checksum(buf)
             struct.pack_into('!H', buf, 2, self.csum)
-        return six.binary_type(buf)
+        return bytes(buf)
 
     def __len__(self):
         return self._MIN_LEN + len(self.srcs) * 4
@@ -381,7 +380,7 @@ class igmpv3_report(igmp):
         if 0 == self.csum:
             self.csum = packet_utils.checksum(buf)
             struct.pack_into('!H', buf, 2, self.csum)
-        return six.binary_type(buf)
+        return bytes(buf)
 
     def __len__(self):
         records_len = 0
@@ -472,12 +471,12 @@ class igmpv3_report_group(stringify.StringifyMixin):
             mod = len(self.aux) % 4
             if mod:
                 self.aux += bytearray(4 - mod)
-                self.aux = six.binary_type(self.aux)
+                self.aux = bytes(self.aux)
             buf.extend(self.aux)
             if 0 == self.aux_len:
                 self.aux_len = len(self.aux) // 4
                 struct.pack_into('!B', buf, 1, self.aux_len)
-        return six.binary_type(buf)
+        return bytes(buf)
 
     def __len__(self):
         return self._MIN_LEN + len(self.srcs) * 4 + self.aux_len * 4
